pub fn clear_config_cache()Expand description
Clears the configuration cache.
This is useful for testing to ensure each test starts with a clean state. In production, clearing the cache will force configs to be re-parsed on next access.
Example
const { clearConfigCache, loadConfig } = require('macroforge-ts');
// Clear cache before each test
clearConfigCache();
// Now load a fresh config
const result = loadConfig(configContent, configPath);